/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.annotations.scr;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import org.nakedosgi.annotations.NullableBoolean;
import static org.nakedosgi.Constants.NO_VALUE;

/**
 * Annotation for defining a component, as per the OSGi Declarative Services 
 * specification
 * @author Evan Cowden
 */
@Documented
@Inherited
@Retention(value = RetentionPolicy.SOURCE)
@Target(value = ElementType.TYPE)
public @interface SCRComponent {

    boolean enabled()  default true;

    /**
     * The name of the component.  If unspecified, the name will be the name
     * of the class
     */
    String name() default NO_VALUE;
    String factory() default NO_VALUE;
    NullableBoolean immediate() default NullableBoolean.UNSPECIFIED;
    /**
     * Specify that the component follows the service factory concept.  Note that
     * if set to true, the component <i>must</i> specify one or more 
     * interfaces to implement.
     */
    boolean serviceFactory() default false;
    /**
     * Override the automatic discovery process and specify a collection of 
     * interfaces implemented by the component.  If left unspecified, the
     * value will be filled in from the interfaces directly implemented
     * by the component.
     */
    Class[] interfaces() default {};
    
    /**
     *  <p>SCR Reference configuration.</p>
     * 
     * <p>Component references that use the event-based binding model
     * should generally be configured with the {@link SCRBind} and 
     * {@link SCRUnbind} annotations instead.</p>
     * @return
     */
    SCRReference[] references() default {};
}
