/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.issuetracking;

import javax.lang.model.element.AnnotationMirror;
import javax.lang.model.element.AnnotationValue;
import javax.lang.model.element.Element;

/**
 * Value objects to track problems encountered when processing
 * Evan Cowden
 */
public class Issue {

    private Element element;
    private AnnotationMirror annotationMirror;
    private AnnotationValue annotationValue;
    private String message;

    public Issue(String message) {
        this.message = message;
    }

    public Issue(Element element, String message) {
        this.element = element;
        this.message = message;
    }

    public Issue(Element element, AnnotationMirror annotationMirror, String message) {
        this.element = element;
        this.annotationMirror = annotationMirror;
        this.message = message;
    }

    public Issue(Element element, AnnotationMirror annotationMirror, AnnotationValue annotationValue, String message) {
        this.element = element;
        this.annotationMirror = annotationMirror;
        this.annotationValue = annotationValue;
        this.message = message;
    }

    public AnnotationMirror getAnnotationMirror() {
        return annotationMirror;
    }

    public void setAnnotationMirror(AnnotationMirror annotationMirror) {
        this.annotationMirror = annotationMirror;
    }

    public AnnotationValue getAnnotationValue() {
        return annotationValue;
    }

    public void setAnnotationValue(AnnotationValue annotationValue) {
        this.annotationValue = annotationValue;
    }

    public Element getElement() {
        return element;
    }

    public void setElement(Element element) {
        this.element = element;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }
}
