/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.manifest;

import java.util.Collection;
import java.util.Map;
import static org.nakedosgi.manifest.ManifestConstants.*;

/**
 * Manifest builder that adds top-level information about a bundle, including 
 * Bundle-Name, Bundle-SymbolicName and Bundle-Version
 * Evan Cowden
 */
public class BundleManifestBuilder {

    /**
     * Append basic manifest entries, if they do not already exist
     * @param manifest
     * @param name
     * @param symbolicName
     * @param version
     */
    public static void addBasicInfo(Map<String, String> manifest, String name, String symbolicName, String version) {
        if (name != null) {
            Util.addIfNewKey(manifest, BUNDLE_NAME_KEY, name);
        }
        if (symbolicName != null) {
            Util.addIfNewKey(manifest, BUNDLE_SYMBOLIC_NAME_KEY, symbolicName);
        }
        if (version != null) {
            Util.addIfNewKey(manifest, BUNDLE_VERSION_KEY, version);
        }
    }

    public static void addBundleActivators(Map<String, String> manifest, Collection<String> bundleActivators) {
        for (String bundleActivator : bundleActivators) {
            Util.appendValue(manifest, ManifestConstants.BUNDLE_ACTIVATOR_KEY, bundleActivator);
        }
    }
}
