/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.processor.scr;

import java.util.Map;
import java.util.Set;
import javax.annotation.processing.Processor;
import javax.annotation.processing.RoundEnvironment;
import javax.annotation.processing.SupportedAnnotationTypes;
import javax.annotation.processing.SupportedSourceVersion;
import javax.lang.model.SourceVersion;
import javax.lang.model.element.Element;
import javax.lang.model.element.ExecutableElement;
import javax.lang.model.element.TypeElement;
import org.nakedosgi.annotations.scr.SCRUnbind;
import org.nakedosgi.processor.OSGiProcessor;
import org.nakedosgi.processor.scr.model.Component;
import org.nakedosgi.processor.scr.model.Reference;
import org.nakedosgi.spi.ServiceProvider;

/**
 * Processor for the {@link SCRUnbind} annotation
 * @author Evan Cowden
 */
@ServiceProvider(Processor.class)
@SupportedSourceVersion(SourceVersion.RELEASE_6)
@SupportedAnnotationTypes("org.nakedosgi.annotations.scr.SCRUnbind")
public class SCRUnbindProcessor extends OSGiProcessor {

    @Override
    public boolean processBundle(Set<? extends TypeElement> annotations, RoundEnvironment roundEnv) {
        Set<? extends Element> elements = roundEnv.getElementsAnnotatedWith(SCRUnbind.class);
        Map<String, Component> components = SCRProcessingUtil.getComponents();
        
        for (Element rawElement : elements) {
            ExecutableElement element = (ExecutableElement) rawElement;

            if (BindUnbindUtil.parametersAreInvalid(element)) {
                continue;
            }

            //Get all necessary objects
            //...annotation & name
            SCRUnbind annotation = element.getAnnotation(SCRUnbind.class);
            String annotationName = annotation.name();
            String name = BindUnbindUtil.getName(element, annotationName);

            //...Model components
            Component component = SCRProcessingUtil.getComponent(element, components);
            Reference reference = BindUnbindUtil.getReference(name, component);

            //...bind
            String unbind = element.getSimpleName().toString();
            reference.setUnbind(unbind);
        }
        
        return true;
    }

}
